@@ -1,4 +1,3 @@
-import time
 from pytorch_lightning.callbacks import ModelCheckpoint, EarlyStopping
 from torchility import Trainer
 from torch.utils.data import DataLoader, random_split
@@ -47,21 +46,27 @@ acc = 'acc', Accuracy(task='multiclass', num_classes=10)
 acc1 = 'acc1', Accuracy(task='multiclass', average='macro', num_classes=10)
 f1 = 'f1', F1Score(task='multiclass', average='macro', num_classes=10)
 
-# 每个epoch保存一次模型的callback
-chkpoint_cbk = ModelCheckpoint(monitor='val_loss', dirpath='./checkpoints/',
-                               filename=f'time={int(time.time())}'+'-{epoch:03d}-{val_loss_epoch:.4f}',
-                               save_top_k=1, mode='min', every_n_epochs=1)
+def acc2(preds, targets):
+    preds = preds.argmax(1)
+    return (preds == targets).float().mean()
+
+def acc3(preds, targets):
+    """一个函数计算多个指标"""
+    preds = preds.argmax(1)
+    return {'a':(preds == targets).float().mean(), 'b':(preds == targets).float().mean()}
+
 # 早停callback
 early_stop_cbk = EarlyStopping(monitor='val_loss', min_delta=0.00, patience=3, verbose=False, mode='min')
+model_cbk = ModelCheckpoint(save_top_k=1, monitor='val_loss', mode='min')
 
 # 训练器，使用新的进度条，以及其他callbacks
 trainer = Trainer(model, F.cross_entropy, [opt, scheduler], epochs=10,
-                  metrics=[acc, acc1],
+                  metrics=[acc, acc1, acc2, acc3],
                   callbacks=[
-                                chkpoint_cbk,       # checkkpoint
+                                model_cbk,
                                 early_stop_cbk,     # 早停
                             ])
 progress = trainer.fit(train_dl, val_dl)            # 训练、验证
-trainer.test(test_dl, metrics=[f1], do_loss=False)  # 测试：metrics用于指定测试专用的指标，do_loss用于指定是否计算测试损失
+trainer.test(test_dl, metrics=[f1, acc2, acc3], do_loss=False)  # 测试：metrics用于指定测试专用的指标，do_loss用于指定是否计算测试损失
 
 print(progress)  # 训练过程，包括训练和验证中的损失和其他指标
